==> seller-config-client-api-4.0.34-20220402.063117-4-sources.jar: com/xforceplus/seller/config/client/translater/MsConfigQueryRequestTranslater.java <==
package com.xforceplus.seller.config.client.translater;/**
 * Created by admin on 2018/11/19.
 */

import com.xforceplus.seller.config.client.model.MsConfigQueryRequest;
import com.xforceplus.seller.config.client.model.MsConfigQueryRequestWithUserInfo;

/**
 * @Author zzw
 * @Description
 * @Date
 * @return
 **/
public class MsConfigQueryRequestTranslater {
    public static  MsConfigQueryRequest MsConfigQueryRequestWithUser2MsConfigQueryRequest(MsConfigQueryRequestWithUserInfo source) {
        //TODO should use orika mapper instead.
        MsConfigQueryRequest target = new MsConfigQueryRequest();
        target.setConfigId(source.getConfigId());
        target.setConfigType(source.getConfigType());
        target.setBusinessBillType(source.getBusinessBillType() ==null?null:source.getBusinessBillType());
        target.setSalesbillType(source.getSalesbillType()==null?null:source.getSalesbillType());
        target.setSellerGroupId(source.getSellerGroupId()==null?null:source.getSellerGroupId());
        target.setSellerName(source.getSellerName() ==null?null:source.getSellerName() );
        target.setSellerTaxNo(source.getSellerTaxNo() ==null?null:source.getSellerTaxNo() );
        target.setSellerNo(source.getSellerNo()==null?null:source.getSellerNo());
        target.setPurchaserGroupId(source.getPurchaserGroupId() ==null?null:source.getPurchaserGroupId() );
        target.setPurchaserName(source.getPurchaserName() ==null?null:source.getPurchaserName() );
        target.setPurchaserTaxNo(source.getPurchaserTaxNo()==null?null:source.getPurchaserTaxNo());
        target.setPurchaserNo(source.getPurchaserNo() ==null?null:source.getPurchaserNo() );
        target.setConfigName(source.getConfigName()==null?null:source.getConfigName());
        target.setInvoiceType(source.getInvoiceType()==null?null:source.getInvoiceType());
        target.setPageNo(source.getPageNo());
        target.setPageSize(source.getPageSize());
        target.setInvoiceType(source.getInvoiceType()==null?null:source.getInvoiceType());
        target.setStatus(source.getStatus()==null?null:source.getStatus());
        target.setExt1(source.getExt1() ==null?null:source.getExt1() );
        target.setExt2(source.getExt2() ==null?null:source.getExt2() );
        target.setExt3( source.getExt3()==null?null:source.getExt3());
        target.setExt4(source.getExt4()==null?null:source.getExt4());
        target.setExt5( source.getExt5()==null?null:source.getExt5());
        target.setExt6(source.getExt6()==null?null:source.getExt6());
        target.setExt7(source.getExt7()==null?null:source.getExt7());
        target.setExt8(source.getExt8()==null?null:source.getExt8());
        target.setExt9(source.getExt9()==null?null:source.getExt9());
        target.setExt10(source.getExt10()==null?null:source.getExt10());
        target.setExt11(source.getExt11()==null?null:source.getExt11());
        target.setExt12(source.getExt12()==null?null:source.getExt12());
        target.setExt13(source.getExt13()==null?null:source.getExt13());
        target.setExt14(source.getExt14()==null?null:source.getExt14());
        target.setExt15(source.getExt15()==null?null:source.getExt15());
        target.setExt16(source.getExt16()==null?null:source.getExt16());
        target.setExt17(source.getExt17()==null?null:source.getExt17());
        target.setExt18(source.getExt18()==null?null:source.getExt18());
        target.setExt19(source.getExt19()==null?null:source.getExt19());
        target.setExt20(source.getExt20()==null?null:source.getExt20());
        target.setExt21(source.getExt21()==null?null:source.getExt21());
        target.setExt22(source.getExt22()==null?null:source.getExt22());
        target.setExt23(source.getExt23() == null ? null : source.getExt23());
        target.setExt24(source.getExt24()==null?null:source.getExt24());
        target.setExt25(source.getExt25()==null?null:source.getExt25());
        return target;
     }


    public static   MsConfigQueryRequestWithUserInfo msConfigQueryRequest2MsConfigQueryRequestWithUser(MsConfigQueryRequest source) {
        MsConfigQueryRequestWithUserInfo target = new MsConfigQueryRequestWithUserInfo();
        target.setConfigId(source.getConfigId());
        target.setConfigType(source.getConfigType());
        target.setStatus(source.getStatus()==null?null:source.getStatus());
        target.setBusinessBillType(source.getBusinessBillType() ==null?null:source.getBusinessBillType());
        target.setSalesbillType(source.getSalesbillType()==null?null:source.getSalesbillType());
        target.setSellerGroupId(source.getSellerGroupId()==null?null:source.getSellerGroupId());
        target.setSellerName(source.getSellerName() ==null?null:source.getSellerName() );
        target.setSellerTaxNo(source.getSellerTaxNo() ==null?null:source.getSellerTaxNo() );
        target.setSellerNo(source.getSellerNo()==null?null:source.getSellerNo());
        target.setPurchaserGroupId(source.getPurchaserGroupId() ==null?null:source.getPurchaserGroupId() );
        target.setPurchaserName(source.getPurchaserName() ==null?null:source.getPurchaserName() );
        target.setPurchaserTaxNo(source.getPurchaserTaxNo()==null?null:source.getPurchaserTaxNo());
        target.setPurchaserNo(source.getPurchaserNo() ==null?null:source.getPurchaserNo() );
        target.setConfigName(source.getConfigName()==null?null:source.getConfigName());
        target.setInvoiceType(source.getInvoiceType()==null?null:source.getInvoiceType());
        target.setPageNo(source.getPageNo());
        target.setPageSize(source.getPageSize());
        target.setExt1(source.getExt1() ==null?null:source.getExt1() );
        target.setExt2(source.getExt2() ==null?null:source.getExt2() );
        target.setExt3( source.getExt3()==null?null:source.getExt3());
        target.setExt4(source.getExt4()==null?null:source.getExt4());
        target.setExt5( source.getExt5()==null?null:source.getExt5());
        target.setExt6(source.getExt6()==null?null:source.getExt6());
        target.setExt7(source.getExt7()==null?null:source.getExt7());
        target.setExt8(source.getExt8()==null?null:source.getExt8());
        target.setExt9(source.getExt9()==null?null:source.getExt9());
        target.setExt10(source.getExt10()==null?null:source.getExt10());
        target.setExt11(source.getExt11()==null?null:source.getExt11());
        target.setExt12(source.getExt12()==null?null:source.getExt12());
        target.setExt13(source.getExt13()==null?null:source.getExt13());
        target.setExt14(source.getExt14()==null?null:source.getExt14());
        target.setExt15(source.getExt15()==null?null:source.getExt15());
        target.setExt16(source.getExt16()==null?null:source.getExt16());
        target.setExt17(source.getExt17()==null?null:source.getExt17());
        target.setExt18(source.getExt18()==null?null:source.getExt18());
        target.setExt19(source.getExt19()==null?null:source.getExt19());
        target.setExt20(source.getExt20()==null?null:source.getExt20());
        target.setExt21(source.getExt21()==null?null:source.getExt21());
        target.setExt22(source.getExt22()==null?null:source.getExt22());
        target.setExt23(source.getExt23() == null ? null : source.getExt23());
        target.setExt24(source.getExt24()==null?null:source.getExt24());
        target.setExt25(source.getExt25()==null?null:source.getExt25());
        return target;
    }
}

==> seller-config-client-api-4.1.30-20250926.030812-1-sources.jar: com/xforceplus/seller/config/client/translater/MsConfigQueryRequestTranslater.java <==
package com.xforceplus.seller.config.client.translater;/**
 * Created by admin on 2018/11/19.
 */

import com.xforceplus.seller.config.client.model.MsConfigQueryRequest;
import com.xforceplus.seller.config.client.model.MsConfigQueryRequestWithUserInfo;
import org.apache.commons.collections4.CollectionUtils;

/**
 * @Author zzw
 * @Description
 * @Date
 * @return
 **/
public class MsConfigQueryRequestTranslater {
    public static  MsConfigQueryRequest MsConfigQueryRequestWithUser2MsConfigQueryRequest(MsConfigQueryRequestWithUserInfo source) {
        //TODO should use orika mapper instead.
        MsConfigQueryRequest target = new MsConfigQueryRequest();
        target.setConfigId(source.getConfigId());
        target.setConfigType(source.getConfigType());
        target.setBusinessBillType(source.getBusinessBillType() ==null?null:source.getBusinessBillType());
        target.setSalesbillType(source.getSalesbillType()==null?null:source.getSalesbillType());
        target.setSalesbillTypes(CollectionUtils.isEmpty(source.getSalesbillTypes()) ? null : source.getSalesbillTypes());
        target.setSellerGroupId(source.getSellerGroupId()==null?null:source.getSellerGroupId());
        target.setSellerName(source.getSellerName() ==null?null:source.getSellerName() );
        target.setSellerTaxNo(source.getSellerTaxNo() ==null?null:source.getSellerTaxNo() );
        target.setSellerNo(source.getSellerNo()==null?null:source.getSellerNo());
        target.setPurchaserGroupId(source.getPurchaserGroupId() ==null?null:source.getPurchaserGroupId() );
        target.setPurchaserName(source.getPurchaserName() ==null?null:source.getPurchaserName() );
        target.setPurchaserTaxNo(source.getPurchaserTaxNo()==null?null:source.getPurchaserTaxNo());
        target.setPurchaserNo(source.getPurchaserNo() ==null?null:source.getPurchaserNo() );
        target.setIssuerGroupId(source.getIssuerGroupId() ==null?null:source.getIssuerGroupId() );
        target.setIssuerName(source.getIssuerName() ==null?null:source.getIssuerName() );
        target.setIssuerTaxNo(source.getIssuerTaxNo()==null?null:source.getIssuerTaxNo());
        target.setIssuerNo(source.getIssuerNo() ==null?null:source.getIssuerNo() );
        target.setConfigName(source.getConfigName()==null?null:source.getConfigName());
        target.setInvoiceType(source.getInvoiceType()==null?null:source.getInvoiceType());
        target.setSysOrgId(source.getSysOrgId());
        target.setTaxInvoiceSource(source.getTaxInvoiceSource());
        target.setPageNo(source.getPageNo());
        target.setPageSize(source.getPageSize());
        target.setInvoiceType(source.getInvoiceType()==null?null:source.getInvoiceType());
        target.setStatus(source.getStatus()==null?null:source.getStatus());
        target.setExt1(source.getExt1() ==null?null:source.getExt1() );
        target.setExt2(source.getExt2() ==null?null:source.getExt2() );
        target.setExt3( source.getExt3()==null?null:source.getExt3());
        target.setExt4(source.getExt4()==null?null:source.getExt4());
        target.setExt5( source.getExt5()==null?null:source.getExt5());
        target.setExt6(source.getExt6()==null?null:source.getExt6());
        target.setExt7(source.getExt7()==null?null:source.getExt7());
        target.setExt8(source.getExt8()==null?null:source.getExt8());
        target.setExt9(source.getExt9()==null?null:source.getExt9());
        target.setExt10(source.getExt10()==null?null:source.getExt10());
        target.setExt11(source.getExt11()==null?null:source.getExt11());
        target.setExt12(source.getExt12()==null?null:source.getExt12());
        target.setExt13(source.getExt13()==null?null:source.getExt13());
        target.setExt14(source.getExt14()==null?null:source.getExt14());
        target.setExt15(source.getExt15()==null?null:source.getExt15());
        target.setExt16(source.getExt16()==null?null:source.getExt16());
        target.setExt17(source.getExt17()==null?null:source.getExt17());
        target.setExt18(source.getExt18()==null?null:source.getExt18());
        target.setExt19(source.getExt19()==null?null:source.getExt19());
        target.setExt20(source.getExt20()==null?null:source.getExt20());
        target.setExt21(source.getExt21()==null?null:source.getExt21());
        target.setExt22(source.getExt22()==null?null:source.getExt22());
        target.setExt23(source.getExt23() == null ? null : source.getExt23());
        target.setExt24(source.getExt24()==null?null:source.getExt24());
        target.setExt25(source.getExt25()==null?null:source.getExt25());
        return target;
     }


    public static   MsConfigQueryRequestWithUserInfo msConfigQueryRequest2MsConfigQueryRequestWithUser(MsConfigQueryRequest source) {
        MsConfigQueryRequestWithUserInfo target = new MsConfigQueryRequestWithUserInfo();
        target.setConfigId(source.getConfigId());
        target.setConfigType(source.getConfigType());
        target.setStatus(source.getStatus()==null?null:source.getStatus());
        target.setBusinessBillType(source.getBusinessBillType() ==null?null:source.getBusinessBillType());
        target.setSalesbillType(source.getSalesbillType()==null?null:source.getSalesbillType());
        target.setSalesbillTypes(CollectionUtils.isEmpty(source.getSalesbillTypes()) ? null : source.getSalesbillTypes());
        target.setSellerGroupId(source.getSellerGroupId()==null?null:source.getSellerGroupId());
        target.setSellerName(source.getSellerName() ==null?null:source.getSellerName() );
        target.setSellerTaxNo(source.getSellerTaxNo() ==null?null:source.getSellerTaxNo() );
        target.setSellerNo(source.getSellerNo()==null?null:source.getSellerNo());
        target.setPurchaserGroupId(source.getPurchaserGroupId() ==null?null:source.getPurchaserGroupId() );
        target.setPurchaserName(source.getPurchaserName() ==null?null:source.getPurchaserName() );
        target.setPurchaserTaxNo(source.getPurchaserTaxNo()==null?null:source.getPurchaserTaxNo());
        target.setPurchaserNo(source.getPurchaserNo() ==null?null:source.getPurchaserNo() );
        target.setConfigName(source.getConfigName()==null?null:source.getConfigName());
        target.setInvoiceType(source.getInvoiceType()==null?null:source.getInvoiceType());
        target.setSysOrgId(source.getSysOrgId());
        target.setTaxInvoiceSource(source.getTaxInvoiceSource());
        target.setPageNo(source.getPageNo());
        target.setPageSize(source.getPageSize());
        target.setExt1(source.getExt1() ==null?null:source.getExt1() );
        target.setExt2(source.getExt2() ==null?null:source.getExt2() );
        target.setExt3( source.getExt3()==null?null:source.getExt3());
        target.setExt4(source.getExt4()==null?null:source.getExt4());
        target.setExt5( source.getExt5()==null?null:source.getExt5());
        target.setExt6(source.getExt6()==null?null:source.getExt6());
        target.setExt7(source.getExt7()==null?null:source.getExt7());
        target.setExt8(source.getExt8()==null?null:source.getExt8());
        target.setExt9(source.getExt9()==null?null:source.getExt9());
        target.setExt10(source.getExt10()==null?null:source.getExt10());
        target.setExt11(source.getExt11()==null?null:source.getExt11());
        target.setExt12(source.getExt12()==null?null:source.getExt12());
        target.setExt13(source.getExt13()==null?null:source.getExt13());
        target.setExt14(source.getExt14()==null?null:source.getExt14());
        target.setExt15(source.getExt15()==null?null:source.getExt15());
        target.setExt16(source.getExt16()==null?null:source.getExt16());
        target.setExt17(source.getExt17()==null?null:source.getExt17());
        target.setExt18(source.getExt18()==null?null:source.getExt18());
        target.setExt19(source.getExt19()==null?null:source.getExt19());
        target.setExt20(source.getExt20()==null?null:source.getExt20());
        target.setExt21(source.getExt21()==null?null:source.getExt21());
        target.setExt22(source.getExt22()==null?null:source.getExt22());
        target.setExt23(source.getExt23() == null ? null : source.getExt23());
        target.setExt24(source.getExt24()==null?null:source.getExt24());
        target.setExt25(source.getExt25()==null?null:source.getExt25());
        return target;
    }
}
